@@ -24,5 +24,6 @@ if __name__ == '__main__':
    text = get_full_text_from_html(site)
    cits = get_citations_with_extra_info(text)
    print(cits)
-   data = get_cellar_extra(sd='2023-01-01',max_ecli=100,save_file='n')
-   b=2
\ No newline at end of file
+   data,d2 = get_cellar_extra(sd='2023-01-01',max_ecli=100,save_file='n')
+   nodes_edges = get_nodes_and_edges_lists(data)
+   pass
\ No newline at end of file
